# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_LABEL_IMPORT_METADATA = Metadata(
    id="8ebfebc97768bf77ee4f3467a6f745021a8c3a59.workbench",
    name="volume-label-import",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_VolumeLabelImportParamsDictNoTag = typing.TypedDict('_VolumeLabelImportParamsDictNoTag', {
    "input": InputPathType,
    "label-list-file": str,
    "output": str,
    "file": typing.NotRequired[str | None],
    "subvol": typing.NotRequired[str | None],
    "value": typing.NotRequired[int | None],
    "drop-unused-labels": bool,
    "discard-others": bool,
})
VolumeLabelImportParamsDictTagged = typing.TypedDict('VolumeLabelImportParamsDictTagged', {
    "@type": typing.Literal["workbench/volume-label-import"],
    "input": InputPathType,
    "label-list-file": str,
    "output": str,
    "file": typing.NotRequired[str | None],
    "subvol": typing.NotRequired[str | None],
    "value": typing.NotRequired[int | None],
    "drop-unused-labels": bool,
    "discard-others": bool,
})
VolumeLabelImportParamsDict = _VolumeLabelImportParamsDictNoTag | VolumeLabelImportParamsDictTagged


class VolumeLabelImportOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeLabelImportParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """the output workbench label volume"""


def volume_label_import_params(
    input_: InputPathType,
    label_list_file: str,
    output: str,
    file: str | None = None,
    subvol: str | None = None,
    value: int | None = None,
    drop_unused_labels: bool = False,
    discard_others: bool = False,
) -> VolumeLabelImportParamsDictTagged:
    """
    Build parameters.
    
    Args:
        input_: the input volume file.
        label_list_file: text file containing the values and names for labels.
        output: the output workbench label volume.
        file: read label name hierarchy from a json file\
            \
            the input json file.
        subvol: select a single subvolume to import\
            \
            the subvolume number or name.
        value: set the value that will be interpreted as unlabeled\
            \
            the numeric value for unlabeled (default 0).
        drop_unused_labels: remove any unused label values from the label table.
        discard_others: set any voxels with values not mentioned in the label\
            list to the ??? label.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-label-import",
        "input": input_,
        "label-list-file": label_list_file,
        "output": output,
        "drop-unused-labels": drop_unused_labels,
        "discard-others": discard_others,
    }
    if file is not None:
        params["file"] = file
    if subvol is not None:
        params["subvol"] = subvol
    if value is not None:
        params["value"] = value
    return params


def volume_label_import_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `VolumeLabelImportParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("input", None) is None:
        raise StyxValidationError("`input` must not be None")
    if not isinstance(params["input"], (pathlib.Path, str)):
        raise StyxValidationError(f'`input` has the wrong type: Received `{type(params.get("input", None))}` expected `InputPathType`')
    if params.get("label-list-file", None) is None:
        raise StyxValidationError("`label-list-file` must not be None")
    if not isinstance(params["label-list-file"], str):
        raise StyxValidationError(f'`label-list-file` has the wrong type: Received `{type(params.get("label-list-file", None))}` expected `str`')
    if params.get("output", None) is None:
        raise StyxValidationError("`output` must not be None")
    if not isinstance(params["output"], str):
        raise StyxValidationError(f'`output` has the wrong type: Received `{type(params.get("output", None))}` expected `str`')
    if params.get("file", None) is not None:
        if not isinstance(params["file"], str):
            raise StyxValidationError(f'`file` has the wrong type: Received `{type(params.get("file", None))}` expected `str | None`')
    if params.get("subvol", None) is not None:
        if not isinstance(params["subvol"], str):
            raise StyxValidationError(f'`subvol` has the wrong type: Received `{type(params.get("subvol", None))}` expected `str | None`')
    if params.get("value", None) is not None:
        if not isinstance(params["value"], int):
            raise StyxValidationError(f'`value` has the wrong type: Received `{type(params.get("value", None))}` expected `int | None`')
    if params.get("drop-unused-labels", False) is None:
        raise StyxValidationError("`drop-unused-labels` must not be None")
    if not isinstance(params["drop-unused-labels"], bool):
        raise StyxValidationError(f'`drop-unused-labels` has the wrong type: Received `{type(params.get("drop-unused-labels", False))}` expected `bool`')
    if params.get("discard-others", False) is None:
        raise StyxValidationError("`discard-others` must not be None")
    if not isinstance(params["discard-others"], bool):
        raise StyxValidationError(f'`discard-others` has the wrong type: Received `{type(params.get("discard-others", False))}` expected `bool`')


def volume_label_import_cargs(
    params: VolumeLabelImportParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-volume-label-import"
    ])
    cargs.append(execution.input_file(params.get("input", None)))
    cargs.append(params.get("label-list-file", None))
    cargs.append(params.get("output", None))
    if params.get("file", None) is not None:
        cargs.extend([
            "-hierarchy",
            params.get("file", None)
        ])
    if params.get("subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("subvol", None)
        ])
    if params.get("value", None) is not None:
        cargs.extend([
            "-unlabeled-value",
            str(params.get("value", None))
        ])
    if params.get("drop-unused-labels", False):
        cargs.append("-drop-unused-labels")
    if params.get("discard-others", False):
        cargs.append("-discard-others")
    return cargs


def volume_label_import_outputs(
    params: VolumeLabelImportParamsDict,
    execution: Execution,
) -> VolumeLabelImportOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeLabelImportOutputs(
        root=execution.output_file("."),
        output=execution.output_file(params.get("output", None)),
    )
    return ret


def volume_label_import_execute(
    params: VolumeLabelImportParamsDict,
    runner: Runner | None = None,
) -> VolumeLabelImportOutputs:
    """
    IMPORT A LABEL VOLUME TO WORKBENCH FORMAT.
    
    Creates a label volume from an integer-valued volume file. The label name
    and color information is stored in the volume header in a nifti extension,
    with a similar format as in caret5, see -volume-help. You may specify the
    empty string (use "") for <label-list-file>, which will be treated as if it
    is an empty file. The label list file must have the following format (2
    lines per label):
    
    <labelname>
    <key> <red> <green> <blue> <alpha>
    ...
    
    Label names are specified on a separate line from their value and color, in
    order to let label names contain spaces. Whitespace is trimmed from both
    ends of the label name, but is kept if it is in the middle of a label. Do
    not specify the "unlabeled" key in the file, it is assumed that 0 means not
    labeled unless -unlabeled-value is specified. The value of <key> specifies
    what value in the imported file should be used as this label (these same key
    values are also used in the output file). The values of <red>, <green>,
    <blue> and <alpha> must be integers from 0 to 255, and will specify the
    color the label is drawn as (alpha of 255 means fully opaque, which is
    probably what you want).
    
    By default, it will create new label names with names like LABEL_5 for any
    values encountered that are not mentioned in the list file, specify
    -discard-others to instead set these values to the "unlabeled" key.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelImportOutputs`).
    """
    volume_label_import_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_LABEL_IMPORT_METADATA)
    params = execution.params(params)
    cargs = volume_label_import_cargs(params, execution)
    ret = volume_label_import_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_label_import(
    input_: InputPathType,
    label_list_file: str,
    output: str,
    file: str | None = None,
    subvol: str | None = None,
    value: int | None = None,
    drop_unused_labels: bool = False,
    discard_others: bool = False,
    runner: Runner | None = None,
) -> VolumeLabelImportOutputs:
    """
    IMPORT A LABEL VOLUME TO WORKBENCH FORMAT.
    
    Creates a label volume from an integer-valued volume file. The label name
    and color information is stored in the volume header in a nifti extension,
    with a similar format as in caret5, see -volume-help. You may specify the
    empty string (use "") for <label-list-file>, which will be treated as if it
    is an empty file. The label list file must have the following format (2
    lines per label):
    
    <labelname>
    <key> <red> <green> <blue> <alpha>
    ...
    
    Label names are specified on a separate line from their value and color, in
    order to let label names contain spaces. Whitespace is trimmed from both
    ends of the label name, but is kept if it is in the middle of a label. Do
    not specify the "unlabeled" key in the file, it is assumed that 0 means not
    labeled unless -unlabeled-value is specified. The value of <key> specifies
    what value in the imported file should be used as this label (these same key
    values are also used in the output file). The values of <red>, <green>,
    <blue> and <alpha> must be integers from 0 to 255, and will specify the
    color the label is drawn as (alpha of 255 means fully opaque, which is
    probably what you want).
    
    By default, it will create new label names with names like LABEL_5 for any
    values encountered that are not mentioned in the list file, specify
    -discard-others to instead set these values to the "unlabeled" key.
    
    Args:
        input_: the input volume file.
        label_list_file: text file containing the values and names for labels.
        output: the output workbench label volume.
        file: read label name hierarchy from a json file\
            \
            the input json file.
        subvol: select a single subvolume to import\
            \
            the subvolume number or name.
        value: set the value that will be interpreted as unlabeled\
            \
            the numeric value for unlabeled (default 0).
        drop_unused_labels: remove any unused label values from the label table.
        discard_others: set any voxels with values not mentioned in the label\
            list to the ??? label.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelImportOutputs`).
    """
    params = volume_label_import_params(
        input_=input_,
        label_list_file=label_list_file,
        output=output,
        file=file,
        subvol=subvol,
        value=value,
        drop_unused_labels=drop_unused_labels,
        discard_others=discard_others,
    )
    return volume_label_import_execute(params, runner)


__all__ = [
    "VOLUME_LABEL_IMPORT_METADATA",
    "VolumeLabelImportOutputs",
    "VolumeLabelImportParamsDict",
    "VolumeLabelImportParamsDictTagged",
    "volume_label_import",
    "volume_label_import_execute",
    "volume_label_import_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ZIP_SCENE_FILE_METADATA = Metadata(
    id="b259c5172b5ae3668ffcdba00a5b5a9f3c90cbb1.workbench",
    name="zip-scene-file",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_ZipSceneFileParamsDictNoTag = typing.TypedDict('_ZipSceneFileParamsDictNoTag', {
    "scene-file": str,
    "extract-folder": str,
    "zip-file": str,
    "directory": typing.NotRequired[str | None],
    "write-scene-file": bool,
    "skip-missing": bool,
})
ZipSceneFileParamsDictTagged = typing.TypedDict('ZipSceneFileParamsDictTagged', {
    "@type": typing.Literal["workbench/zip-scene-file"],
    "scene-file": str,
    "extract-folder": str,
    "zip-file": str,
    "directory": typing.NotRequired[str | None],
    "write-scene-file": bool,
    "skip-missing": bool,
})
ZipSceneFileParamsDict = _ZipSceneFileParamsDictNoTag | ZipSceneFileParamsDictTagged


class ZipSceneFileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ZipSceneFileParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def zip_scene_file_params(
    scene_file: str,
    extract_folder: str,
    zip_file: str,
    directory: str | None = None,
    write_scene_file: bool = False,
    skip_missing: bool = False,
) -> ZipSceneFileParamsDictTagged:
    """
    Build parameters.
    
    Args:
        scene_file: the scene file to make the zip file from.
        extract_folder: the name of the folder created when the zip file is\
            unzipped.
        zip_file: out - the zip file that will be created.
        directory: specify a directory that all data files are somewhere\
            within, this will become the root of the zipfile's directory structure\
            \
            the directory.
        write_scene_file: rewrite the scene file before zipping, to store a new\
            base path or fix extra '..'s in paths that might break.
        skip_missing: any missing files will generate only warnings, and the\
            zip file will be created anyway.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/zip-scene-file",
        "scene-file": scene_file,
        "extract-folder": extract_folder,
        "zip-file": zip_file,
        "write-scene-file": write_scene_file,
        "skip-missing": skip_missing,
    }
    if directory is not None:
        params["directory"] = directory
    return params


def zip_scene_file_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `ZipSceneFileParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("scene-file", None) is None:
        raise StyxValidationError("`scene-file` must not be None")
    if not isinstance(params["scene-file"], str):
        raise StyxValidationError(f'`scene-file` has the wrong type: Received `{type(params.get("scene-file", None))}` expected `str`')
    if params.get("extract-folder", None) is None:
        raise StyxValidationError("`extract-folder` must not be None")
    if not isinstance(params["extract-folder"], str):
        raise StyxValidationError(f'`extract-folder` has the wrong type: Received `{type(params.get("extract-folder", None))}` expected `str`')
    if params.get("zip-file", None) is None:
        raise StyxValidationError("`zip-file` must not be None")
    if not isinstance(params["zip-file"], str):
        raise StyxValidationError(f'`zip-file` has the wrong type: Received `{type(params.get("zip-file", None))}` expected `str`')
    if params.get("directory", None) is not None:
        if not isinstance(params["directory"], str):
            raise StyxValidationError(f'`directory` has the wrong type: Received `{type(params.get("directory", None))}` expected `str | None`')
    if params.get("write-scene-file", False) is None:
        raise StyxValidationError("`write-scene-file` must not be None")
    if not isinstance(params["write-scene-file"], bool):
        raise StyxValidationError(f'`write-scene-file` has the wrong type: Received `{type(params.get("write-scene-file", False))}` expected `bool`')
    if params.get("skip-missing", False) is None:
        raise StyxValidationError("`skip-missing` must not be None")
    if not isinstance(params["skip-missing"], bool):
        raise StyxValidationError(f'`skip-missing` has the wrong type: Received `{type(params.get("skip-missing", False))}` expected `bool`')


def zip_scene_file_cargs(
    params: ZipSceneFileParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-zip-scene-file"
    ])
    cargs.append(params.get("scene-file", None))
    cargs.append(params.get("extract-folder", None))
    cargs.append(params.get("zip-file", None))
    if params.get("directory", None) is not None:
        cargs.extend([
            "-base-dir",
            params.get("directory", None)
        ])
    if params.get("write-scene-file", False):
        cargs.append("-write-scene-file")
    if params.get("skip-missing", False):
        cargs.append("-skip-missing")
    return cargs


def zip_scene_file_outputs(
    params: ZipSceneFileParamsDict,
    execution: Execution,
) -> ZipSceneFileOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ZipSceneFileOutputs(
        root=execution.output_file("."),
    )
    return ret


def zip_scene_file_execute(
    params: ZipSceneFileParamsDict,
    runner: Runner | None = None,
) -> ZipSceneFileOutputs:
    """
    ZIP A SCENE FILE AND ITS DATA FILES.
    
    If zip-file already exists, it will be overwritten. If -base-dir is not
    specified, the base directory will be automatically set to the lowest level
    directory containing all files. The scene file must contain only relative
    paths, and no data files may be outside the base directory.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZipSceneFileOutputs`).
    """
    zip_scene_file_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(ZIP_SCENE_FILE_METADATA)
    params = execution.params(params)
    cargs = zip_scene_file_cargs(params, execution)
    ret = zip_scene_file_outputs(params, execution)
    execution.run(cargs)
    return ret


def zip_scene_file(
    scene_file: str,
    extract_folder: str,
    zip_file: str,
    directory: str | None = None,
    write_scene_file: bool = False,
    skip_missing: bool = False,
    runner: Runner | None = None,
) -> ZipSceneFileOutputs:
    """
    ZIP A SCENE FILE AND ITS DATA FILES.
    
    If zip-file already exists, it will be overwritten. If -base-dir is not
    specified, the base directory will be automatically set to the lowest level
    directory containing all files. The scene file must contain only relative
    paths, and no data files may be outside the base directory.
    
    Args:
        scene_file: the scene file to make the zip file from.
        extract_folder: the name of the folder created when the zip file is\
            unzipped.
        zip_file: out - the zip file that will be created.
        directory: specify a directory that all data files are somewhere\
            within, this will become the root of the zipfile's directory structure\
            \
            the directory.
        write_scene_file: rewrite the scene file before zipping, to store a new\
            base path or fix extra '..'s in paths that might break.
        skip_missing: any missing files will generate only warnings, and the\
            zip file will be created anyway.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ZipSceneFileOutputs`).
    """
    params = zip_scene_file_params(
        scene_file=scene_file,
        extract_folder=extract_folder,
        zip_file=zip_file,
        directory=directory,
        write_scene_file=write_scene_file,
        skip_missing=skip_missing,
    )
    return zip_scene_file_execute(params, runner)


__all__ = [
    "ZIP_SCENE_FILE_METADATA",
    "ZipSceneFileOutputs",
    "ZipSceneFileParamsDict",
    "ZipSceneFileParamsDictTagged",
    "zip_scene_file",
    "zip_scene_file_execute",
    "zip_scene_file_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

GIFTI_ALL_LABELS_TO_ROIS_METADATA = Metadata(
    id="0e399afa8268c4aa88310407830c9ce63af9480a.workbench",
    name="gifti-all-labels-to-rois",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_GiftiAllLabelsToRoisParamsDictNoTag = typing.TypedDict('_GiftiAllLabelsToRoisParamsDictNoTag', {
    "label-in": InputPathType,
    "map": str,
    "metric-out": str,
})
GiftiAllLabelsToRoisParamsDictTagged = typing.TypedDict('GiftiAllLabelsToRoisParamsDictTagged', {
    "@type": typing.Literal["workbench/gifti-all-labels-to-rois"],
    "label-in": InputPathType,
    "map": str,
    "metric-out": str,
})
GiftiAllLabelsToRoisParamsDict = _GiftiAllLabelsToRoisParamsDictNoTag | GiftiAllLabelsToRoisParamsDictTagged


class GiftiAllLabelsToRoisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `GiftiAllLabelsToRoisParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def gifti_all_labels_to_rois_params(
    label_in: InputPathType,
    map_: str,
    metric_out: str,
) -> GiftiAllLabelsToRoisParamsDictTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input gifti label file.
        map_: the number or name of the label map to use.
        metric_out: the output metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/gifti-all-labels-to-rois",
        "label-in": label_in,
        "map": map_,
        "metric-out": metric_out,
    }
    return params


def gifti_all_labels_to_rois_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `GiftiAllLabelsToRoisParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("label-in", None) is None:
        raise StyxValidationError("`label-in` must not be None")
    if not isinstance(params["label-in"], (pathlib.Path, str)):
        raise StyxValidationError(f'`label-in` has the wrong type: Received `{type(params.get("label-in", None))}` expected `InputPathType`')
    if params.get("map", None) is None:
        raise StyxValidationError("`map` must not be None")
    if not isinstance(params["map"], str):
        raise StyxValidationError(f'`map` has the wrong type: Received `{type(params.get("map", None))}` expected `str`')
    if params.get("metric-out", None) is None:
        raise StyxValidationError("`metric-out` must not be None")
    if not isinstance(params["metric-out"], str):
        raise StyxValidationError(f'`metric-out` has the wrong type: Received `{type(params.get("metric-out", None))}` expected `str`')


def gifti_all_labels_to_rois_cargs(
    params: GiftiAllLabelsToRoisParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-gifti-all-labels-to-rois"
    ])
    cargs.append(execution.input_file(params.get("label-in", None)))
    cargs.append(params.get("map", None))
    cargs.append(params.get("metric-out", None))
    return cargs


def gifti_all_labels_to_rois_outputs(
    params: GiftiAllLabelsToRoisParamsDict,
    execution: Execution,
) -> GiftiAllLabelsToRoisOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = GiftiAllLabelsToRoisOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric-out", None)),
    )
    return ret


def gifti_all_labels_to_rois_execute(
    params: GiftiAllLabelsToRoisParamsDict,
    runner: Runner | None = None,
) -> GiftiAllLabelsToRoisOutputs:
    """
    MAKE ROIS FROM ALL LABELS IN A GIFTI COLUMN.
    
    The output metric file has a column for each label in the specified input
    map, other than the ??? label, each of which contains an ROI of all vertices
    that are set to the corresponding label.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiAllLabelsToRoisOutputs`).
    """
    gifti_all_labels_to_rois_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_ALL_LABELS_TO_ROIS_METADATA)
    params = execution.params(params)
    cargs = gifti_all_labels_to_rois_cargs(params, execution)
    ret = gifti_all_labels_to_rois_outputs(params, execution)
    execution.run(cargs)
    return ret


def gifti_all_labels_to_rois(
    label_in: InputPathType,
    map_: str,
    metric_out: str,
    runner: Runner | None = None,
) -> GiftiAllLabelsToRoisOutputs:
    """
    MAKE ROIS FROM ALL LABELS IN A GIFTI COLUMN.
    
    The output metric file has a column for each label in the specified input
    map, other than the ??? label, each of which contains an ROI of all vertices
    that are set to the corresponding label.
    
    Args:
        label_in: the input gifti label file.
        map_: the number or name of the label map to use.
        metric_out: the output metric file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiAllLabelsToRoisOutputs`).
    """
    params = gifti_all_labels_to_rois_params(
        label_in=label_in,
        map_=map_,
        metric_out=metric_out,
    )
    return gifti_all_labels_to_rois_execute(params, runner)


__all__ = [
    "GIFTI_ALL_LABELS_TO_ROIS_METADATA",
    "GiftiAllLabelsToRoisOutputs",
    "GiftiAllLabelsToRoisParamsDict",
    "GiftiAllLabelsToRoisParamsDictTagged",
    "gifti_all_labels_to_rois",
    "gifti_all_labels_to_rois_execute",
    "gifti_all_labels_to_rois_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CONVERT_AFFINE_METADATA = Metadata(
    id="f8f331e0186c1d179bf357df5d5eadf7019f39e3.workbench",
    name="convert-affine",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_ConvertAffineFromWorldParamsDictNoTag = typing.TypedDict('_ConvertAffineFromWorldParamsDictNoTag', {
    "input": str,
    "inverse": bool,
})
ConvertAffineFromWorldParamsDictTagged = typing.TypedDict('ConvertAffineFromWorldParamsDictTagged', {
    "@type": typing.Literal["from-world"],
    "input": str,
    "inverse": bool,
})
ConvertAffineFromWorldParamsDict = _ConvertAffineFromWorldParamsDictNoTag | ConvertAffineFromWorldParamsDictTagged


_ConvertAffineFromFlirtParamsDictNoTag = typing.TypedDict('_ConvertAffineFromFlirtParamsDictNoTag', {
    "input": str,
    "source-volume": str,
    "target-volume": str,
})
ConvertAffineFromFlirtParamsDictTagged = typing.TypedDict('ConvertAffineFromFlirtParamsDictTagged', {
    "@type": typing.Literal["from-flirt"],
    "input": str,
    "source-volume": str,
    "target-volume": str,
})
ConvertAffineFromFlirtParamsDict = _ConvertAffineFromFlirtParamsDictNoTag | ConvertAffineFromFlirtParamsDictTagged


_ConvertAffineToWorldParamsDictNoTag = typing.TypedDict('_ConvertAffineToWorldParamsDictNoTag', {
    "output": str,
    "inverse": bool,
})
ConvertAffineToWorldParamsDictTagged = typing.TypedDict('ConvertAffineToWorldParamsDictTagged', {
    "@type": typing.Literal["to-world"],
    "output": str,
    "inverse": bool,
})
ConvertAffineToWorldParamsDict = _ConvertAffineToWorldParamsDictNoTag | ConvertAffineToWorldParamsDictTagged


_ConvertAffineToFlirtParamsDictNoTag = typing.TypedDict('_ConvertAffineToFlirtParamsDictNoTag', {
    "output": str,
    "source-volume": str,
    "target-volume": str,
})
ConvertAffineToFlirtParamsDictTagged = typing.TypedDict('ConvertAffineToFlirtParamsDictTagged', {
    "@type": typing.Literal["to-flirt"],
    "output": str,
    "source-volume": str,
    "target-volume": str,
})
ConvertAffineToFlirtParamsDict = _ConvertAffineToFlirtParamsDictNoTag | ConvertAffineToFlirtParamsDictTagged


_ConvertAffineParamsDictNoTag = typing.TypedDict('_ConvertAffineParamsDictNoTag', {
    "from-world": typing.NotRequired[ConvertAffineFromWorldParamsDict | None],
    "from-flirt": typing.NotRequired[ConvertAffineFromFlirtParamsDict | None],
    "to-world": typing.NotRequired[ConvertAffineToWorldParamsDict | None],
    "to-flirt": typing.NotRequired[list[ConvertAffineToFlirtParamsDict] | None],
    "output": typing.NotRequired[str | None],
    "input": typing.NotRequired[str | None],
})
ConvertAffineParamsDictTagged = typing.TypedDict('ConvertAffineParamsDictTagged', {
    "@type": typing.Literal["workbench/convert-affine"],
    "from-world": typing.NotRequired[ConvertAffineFromWorldParamsDict | None],
    "from-flirt": typing.NotRequired[ConvertAffineFromFlirtParamsDict | None],
    "to-world": typing.NotRequired[ConvertAffineToWorldParamsDict | None],
    "to-flirt": typing.NotRequired[list[ConvertAffineToFlirtParamsDict] | None],
    "output": typing.NotRequired[str | None],
    "input": typing.NotRequired[str | None],
})
ConvertAffineParamsDict = _ConvertAffineParamsDictNoTag | ConvertAffineParamsDictTagged


def convert_affine_from_world(
    input_: str,
    inverse: bool = False,
) -> ConvertAffineFromWorldParamsDictTagged:
    """
    Build parameters.
    
    Args:
        input_: the input affine.
        inverse: for files that use 'target to source' convention.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from-world",
        "input": input_,
        "inverse": inverse,
    }
    return params


def convert_affine_from_world_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `ConvertAffineFromWorldParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("input", None) is None:
        raise StyxValidationError("`input` must not be None")
    if not isinstance(params["input"], str):
        raise StyxValidationError(f'`input` has the wrong type: Received `{type(params.get("input", None))}` expected `str`')
    if params.get("inverse", False) is None:
        raise StyxValidationError("`inverse` must not be None")
    if not isinstance(params["inverse"], bool):
        raise StyxValidationError(f'`inverse` has the wrong type: Received `{type(params.get("inverse", False))}` expected `bool`')


def convert_affine_from_world_cargs(
    params: ConvertAffineFromWorldParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-from-world",
        params.get("input", None)
    ])
    if params.get("inverse", False):
        cargs.append("-inverse")
    return cargs


def convert_affine_from_flirt(
    input_: str,
    source_volume: str,
    target_volume: str,
) -> ConvertAffineFromFlirtParamsDictTagged:
    """
    Build parameters.
    
    Args:
        input_: the input affine.
        source_volume: the source volume used when generating the input affine.
        target_volume: the target volume used when generating the input affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from-flirt",
        "input": input_,
        "source-volume": source_volume,
        "target-volume": target_volume,
    }
    return params


def convert_affine_from_flirt_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `ConvertAffineFromFlirtParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("input", None) is None:
        raise StyxValidationError("`input` must not be None")
    if not isinstance(params["input"], str):
        raise StyxValidationError(f'`input` has the wrong type: Received `{type(params.get("input", None))}` expected `str`')
    if params.get("source-volume", None) is None:
        raise StyxValidationError("`source-volume` must not be None")
    if not isinstance(params["source-volume"], str):
        raise StyxValidationError(f'`source-volume` has the wrong type: Received `{type(params.get("source-volume", None))}` expected `str`')
    if params.get("target-volume", None) is None:
        raise StyxValidationError("`target-volume` must not be None")
    if not isinstance(params["target-volume"], str):
        raise StyxValidationError(f'`target-volume` has the wrong type: Received `{type(params.get("target-volume", None))}` expected `str`')


def convert_affine_from_flirt_cargs(
    params: ConvertAffineFromFlirtParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-from-flirt",
        params.get("input", None),
        params.get("source-volume", None),
        params.get("target-volume", None)
    ])
    return cargs


def convert_affine_to_world(
    output: str,
    inverse: bool = False,
) -> ConvertAffineToWorldParamsDictTagged:
    """
    Build parameters.
    
    Args:
        output: output - the output affine.
        inverse: write file using 'target to source' convention.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to-world",
        "output": output,
        "inverse": inverse,
    }
    return params


def convert_affine_to_world_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `ConvertAffineToWorldParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("output", None) is None:
        raise StyxValidationError("`output` must not be None")
    if not isinstance(params["output"], str):
        raise StyxValidationError(f'`output` has the wrong type: Received `{type(params.get("output", None))}` expected `str`')
    if params.get("inverse", False) is None:
        raise StyxValidationError("`inverse` must not be None")
    if not isinstance(params["inverse"], bool):
        raise StyxValidationError(f'`inverse` has the wrong type: Received `{type(params.get("inverse", False))}` expected `bool`')


def convert_affine_to_world_cargs(
    params: ConvertAffineToWorldParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-to-world",
        params.get("output", None)
    ])
    if params.get("inverse", False):
        cargs.append("-inverse")
    return cargs


def convert_affine_to_flirt(
    output: str,
    source_volume: str,
    target_volume: str,
) -> ConvertAffineToFlirtParamsDictTagged:
    """
    Build parameters.
    
    Args:
        output: output - the output affine.
        source_volume: the volume you want to apply the transform to.
        target_volume: the target space you want the transformed volume to\
            match.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to-flirt",
        "output": output,
        "source-volume": source_volume,
        "target-volume": target_volume,
    }
    return params


def convert_affine_to_flirt_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `ConvertAffineToFlirtParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("output", None) is None:
        raise StyxValidationError("`output` must not be None")
    if not isinstance(params["output"], str):
        raise StyxValidationError(f'`output` has the wrong type: Received `{type(params.get("output", None))}` expected `str`')
    if params.get("source-volume", None) is None:
        raise StyxValidationError("`source-volume` must not be None")
    if not isinstance(params["source-volume"], str):
        raise StyxValidationError(f'`source-volume` has the wrong type: Received `{type(params.get("source-volume", None))}` expected `str`')
    if params.get("target-volume", None) is None:
        raise StyxValidationError("`target-volume` must not be None")
    if not isinstance(params["target-volume"], str):
        raise StyxValidationError(f'`target-volume` has the wrong type: Received `{type(params.get("target-volume", None))}` expected `str`')


def convert_affine_to_flirt_cargs(
    params: ConvertAffineToFlirtParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-to-flirt",
        params.get("output", None),
        params.get("source-volume", None),
        params.get("target-volume", None)
    ])
    return cargs


class ConvertAffineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ConvertAffineParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def convert_affine_params(
    from_world: ConvertAffineFromWorldParamsDict | None = None,
    from_flirt: ConvertAffineFromFlirtParamsDict | None = None,
    to_world: ConvertAffineToWorldParamsDict | None = None,
    to_flirt: list[ConvertAffineToFlirtParamsDict] | None = None,
    output: str | None = None,
    input_: str | None = None,
) -> ConvertAffineParamsDictTagged:
    """
    Build parameters.
    
    Args:
        from_world: input is a NIFTI 'world' affine.
        from_flirt: input is a flirt matrix.
        to_world: write output as a NIFTI 'world' affine.
        to_flirt: write output as a flirt matrix.
        output: write output as an ITK affine\
            \
            output - the output affine.
        input_: input is an ITK matrix\
            \
            the input affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/convert-affine",
    }
    if from_world is not None:
        params["from-world"] = from_world
    if from_flirt is not None:
        params["from-flirt"] = from_flirt
    if to_world is not None:
        params["to-world"] = to_world
    if to_flirt is not None:
        params["to-flirt"] = to_flirt
    if output is not None:
        params["output"] = output
    if input_ is not None:
        params["input"] = input_
    return params


def convert_affine_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `ConvertAffineParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("from-world", None) is not None:
        convert_affine_from_world_validate(params["from-world"])
    if params.get("from-flirt", None) is not None:
        convert_affine_from_flirt_validate(params["from-flirt"])
    if params.get("to-world", None) is not None:
        convert_affine_to_world_validate(params["to-world"])
    if params.get("to-flirt", None) is not None:
        if not isinstance(params["to-flirt"], list):
            raise StyxValidationError(f'`to-flirt` has the wrong type: Received `{type(params.get("to-flirt", None))}` expected `list[ConvertAffineToFlirtParamsDict] | None`')
        for e in params["to-flirt"]:
            convert_affine_to_flirt_validate(e)
    if params.get("output", None) is not None:
        if not isinstance(params["output"], str):
            raise StyxValidationError(f'`output` has the wrong type: Received `{type(params.get("output", None))}` expected `str | None`')
    if params.get("input", None) is not None:
        if not isinstance(params["input"], str):
            raise StyxValidationError(f'`input` has the wrong type: Received `{type(params.get("input", None))}` expected `str | None`')


def convert_affine_cargs(
    params: ConvertAffineParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-convert-affine"
    ])
    if params.get("from-world", None) is not None or params.get("from-flirt", None) is not None or params.get("to-world", None) is not None or params.get("to-flirt", None) is not None:
        cargs.extend([
            *(convert_affine_from_world_cargs(params.get("from-world", None), execution) if (params.get("from-world", None) is not None) else []),
            *(convert_affine_from_flirt_cargs(params.get("from-flirt", None), execution) if (params.get("from-flirt", None) is not None) else []),
            *(convert_affine_to_world_cargs(params.get("to-world", None), execution) if (params.get("to-world", None) is not None) else []),
            *([a for c in [convert_affine_to_flirt_cargs(s, execution) for s in params.get("to-flirt", None)] for a in c] if (params.get("to-flirt", None) is not None) else [])
        ])
    if params.get("output", None) is not None:
        cargs.extend([
            "-to-itk",
            params.get("output", None)
        ])
    if params.get("input", None) is not None:
        cargs.extend([
            "-from-itk",
            params.get("input", None)
        ])
    return cargs


def convert_affine_outputs(
    params: ConvertAffineParamsDict,
    execution: Execution,
) -> ConvertAffineOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = ConvertAffineOutputs(
        root=execution.output_file("."),
    )
    return ret


def convert_affine_execute(
    params: ConvertAffineParamsDict,
    runner: Runner | None = None,
) -> ConvertAffineOutputs:
    """
    CONVERT AN AFFINE FILE BETWEEN CONVENTIONS.
    
    NIFTI world matrices can be used directly on mm coordinates via matrix
    multiplication, they use the NIFTI coordinate system, that is, positive X is
    right, positive Y is anterior, and positive Z is superior. Note that
    wb_command assumes that world matrices transform source coordinates to
    target coordinates, while other tools may use affines that transform target
    coordinates to source coordinates.
    
    The ITK format is used by ANTS.
    
    You must specify exactly one -from option, but you may specify multiple -to
    options, and -to-flirt may be specified more than once.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertAffineOutputs`).
    """
    convert_affine_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_AFFINE_METADATA)
    params = execution.params(params)
    cargs = convert_affine_cargs(params, execution)
    ret = convert_affine_outputs(params, execution)
    execution.run(cargs)
    return ret


def convert_affine(
    from_world: ConvertAffineFromWorldParamsDict | None = None,
    from_flirt: ConvertAffineFromFlirtParamsDict | None = None,
    to_world: ConvertAffineToWorldParamsDict | None = None,
    to_flirt: list[ConvertAffineToFlirtParamsDict] | None = None,
    output: str | None = None,
    input_: str | None = None,
    runner: Runner | None = None,
) -> ConvertAffineOutputs:
    """
    CONVERT AN AFFINE FILE BETWEEN CONVENTIONS.
    
    NIFTI world matrices can be used directly on mm coordinates via matrix
    multiplication, they use the NIFTI coordinate system, that is, positive X is
    right, positive Y is anterior, and positive Z is superior. Note that
    wb_command assumes that world matrices transform source coordinates to
    target coordinates, while other tools may use affines that transform target
    coordinates to source coordinates.
    
    The ITK format is used by ANTS.
    
    You must specify exactly one -from option, but you may specify multiple -to
    options, and -to-flirt may be specified more than once.
    
    Args:
        from_world: input is a NIFTI 'world' affine.
        from_flirt: input is a flirt matrix.
        to_world: write output as a NIFTI 'world' affine.
        to_flirt: write output as a flirt matrix.
        output: write output as an ITK affine\
            \
            output - the output affine.
        input_: input is an ITK matrix\
            \
            the input affine.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertAffineOutputs`).
    """
    params = convert_affine_params(
        from_world=from_world,
        from_flirt=from_flirt,
        to_world=to_world,
        to_flirt=to_flirt,
        output=output,
        input_=input_,
    )
    return convert_affine_execute(params, runner)


__all__ = [
    "CONVERT_AFFINE_METADATA",
    "ConvertAffineFromFlirtParamsDict",
    "ConvertAffineFromFlirtParamsDictTagged",
    "ConvertAffineFromWorldParamsDict",
    "ConvertAffineFromWorldParamsDictTagged",
    "ConvertAffineOutputs",
    "ConvertAffineParamsDict",
    "ConvertAffineParamsDictTagged",
    "ConvertAffineToFlirtParamsDict",
    "ConvertAffineToFlirtParamsDictTagged",
    "ConvertAffineToWorldParamsDict",
    "ConvertAffineToWorldParamsDictTagged",
    "convert_affine",
    "convert_affine_execute",
    "convert_affine_from_flirt",
    "convert_affine_from_world",
    "convert_affine_params",
    "convert_affine_to_flirt",
    "convert_affine_to_world",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_STATS_METADATA = Metadata(
    id="f349676d3d092156442226a065fb86440603b2ac.workbench",
    name="cifti-stats",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_CiftiStatsRoiParamsDictNoTag = typing.TypedDict('_CiftiStatsRoiParamsDictNoTag', {
    "roi-cifti": InputPathType,
    "match-maps": bool,
})
CiftiStatsRoiParamsDictTagged = typing.TypedDict('CiftiStatsRoiParamsDictTagged', {
    "@type": typing.Literal["roi"],
    "roi-cifti": InputPathType,
    "match-maps": bool,
})
CiftiStatsRoiParamsDict = _CiftiStatsRoiParamsDictNoTag | CiftiStatsRoiParamsDictTagged


_CiftiStatsParamsDictNoTag = typing.TypedDict('_CiftiStatsParamsDictNoTag', {
    "cifti-in": InputPathType,
    "roi": typing.NotRequired[CiftiStatsRoiParamsDict | None],
    "column": typing.NotRequired[int | None],
    "percent": typing.NotRequired[float | None],
    "operation": typing.NotRequired[str | None],
    "show-map-name": bool,
})
CiftiStatsParamsDictTagged = typing.TypedDict('CiftiStatsParamsDictTagged', {
    "@type": typing.Literal["workbench/cifti-stats"],
    "cifti-in": InputPathType,
    "roi": typing.NotRequired[CiftiStatsRoiParamsDict | None],
    "column": typing.NotRequired[int | None],
    "percent": typing.NotRequired[float | None],
    "operation": typing.NotRequired[str | None],
    "show-map-name": bool,
})
CiftiStatsParamsDict = _CiftiStatsParamsDictNoTag | CiftiStatsParamsDictTagged


def cifti_stats_roi(
    roi_cifti: InputPathType,
    match_maps: bool = False,
) -> CiftiStatsRoiParamsDictTagged:
    """
    Build parameters.
    
    Args:
        roi_cifti: the roi, as a cifti file.
        match_maps: each column of input uses the corresponding column from the\
            roi file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "roi",
        "roi-cifti": roi_cifti,
        "match-maps": match_maps,
    }
    return params


def cifti_stats_roi_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiStatsRoiParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("roi-cifti", None) is None:
        raise StyxValidationError("`roi-cifti` must not be None")
    if not isinstance(params["roi-cifti"], (pathlib.Path, str)):
        raise StyxValidationError(f'`roi-cifti` has the wrong type: Received `{type(params.get("roi-cifti", None))}` expected `InputPathType`')
    if params.get("match-maps", False) is None:
        raise StyxValidationError("`match-maps` must not be None")
    if not isinstance(params["match-maps"], bool):
        raise StyxValidationError(f'`match-maps` has the wrong type: Received `{type(params.get("match-maps", False))}` expected `bool`')


def cifti_stats_roi_cargs(
    params: CiftiStatsRoiParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-roi",
        execution.input_file(params.get("roi-cifti", None))
    ])
    if params.get("match-maps", False):
        cargs.append("-match-maps")
    return cargs


class CiftiStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiStatsParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_stats_params(
    cifti_in: InputPathType,
    roi: CiftiStatsRoiParamsDict | None = None,
    column: int | None = None,
    percent: float | None = None,
    operation: str | None = None,
    show_map_name: bool = False,
) -> CiftiStatsParamsDictTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti.
        roi: only consider data inside an roi.
        column: only display output for one column\
            \
            the column index (starting from 1).
        percent: give the value at a percentile\
            \
            the percentile to find, must be between 0 and 100.
        operation: use a reduction operation\
            \
            the reduction operation.
        show_map_name: print column index and name before each output.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-stats",
        "cifti-in": cifti_in,
        "show-map-name": show_map_name,
    }
    if roi is not None:
        params["roi"] = roi
    if column is not None:
        params["column"] = column
    if percent is not None:
        params["percent"] = percent
    if operation is not None:
        params["operation"] = operation
    return params


def cifti_stats_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiStatsParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("cifti-in", None) is None:
        raise StyxValidationError("`cifti-in` must not be None")
    if not isinstance(params["cifti-in"], (pathlib.Path, str)):
        raise StyxValidationError(f'`cifti-in` has the wrong type: Received `{type(params.get("cifti-in", None))}` expected `InputPathType`')
    if params.get("roi", None) is not None:
        cifti_stats_roi_validate(params["roi"])
    if params.get("column", None) is not None:
        if not isinstance(params["column"], int):
            raise StyxValidationError(f'`column` has the wrong type: Received `{type(params.get("column", None))}` expected `int | None`')
    if params.get("percent", None) is not None:
        if not isinstance(params["percent"], (float, int)):
            raise StyxValidationError(f'`percent` has the wrong type: Received `{type(params.get("percent", None))}` expected `float | None`')
    if params.get("operation", None) is not None:
        if not isinstance(params["operation"], str):
            raise StyxValidationError(f'`operation` has the wrong type: Received `{type(params.get("operation", None))}` expected `str | None`')
    if params.get("show-map-name", False) is None:
        raise StyxValidationError("`show-map-name` must not be None")
    if not isinstance(params["show-map-name"], bool):
        raise StyxValidationError(f'`show-map-name` has the wrong type: Received `{type(params.get("show-map-name", False))}` expected `bool`')


def cifti_stats_cargs(
    params: CiftiStatsParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-cifti-stats"
    ])
    cargs.append(execution.input_file(params.get("cifti-in", None)))
    if params.get("roi", None) is not None:
        cargs.extend(cifti_stats_roi_cargs(params.get("roi", None), execution))
    if params.get("column", None) is not None:
        cargs.extend([
            "-column",
            str(params.get("column", None))
        ])
    if params.get("percent", None) is not None:
        cargs.extend([
            "-percentile",
            str(params.get("percent", None))
        ])
    if params.get("operation", None) is not None:
        cargs.extend([
            "-reduce",
            params.get("operation", None)
        ])
    if params.get("show-map-name", False):
        cargs.append("-show-map-name")
    return cargs


def cifti_stats_outputs(
    params: CiftiStatsParamsDict,
    execution: Execution,
) -> CiftiStatsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiStatsOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_stats_execute(
    params: CiftiStatsParamsDict,
    runner: Runner | None = None,
) -> CiftiStatsOutputs:
    """
    STATISTICS ALONG CIFTI COLUMNS.
    
    For each column of the input, a line of text is printed, resulting from the
    specified reduction or percentile operation. If -roi is specified without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Use -column to only give
    output for a single data column. Exactly one of -reduce or -percentile must
    be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiStatsOutputs`).
    """
    cifti_stats_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_STATS_METADATA)
    params = execution.params(params)
    cargs = cifti_stats_cargs(params, execution)
    ret = cifti_stats_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_stats(
    cifti_in: InputPathType,
    roi: CiftiStatsRoiParamsDict | None = None,
    column: int | None = None,
    percent: float | None = None,
    operation: str | None = None,
    show_map_name: bool = False,
    runner: Runner | None = None,
) -> CiftiStatsOutputs:
    """
    STATISTICS ALONG CIFTI COLUMNS.
    
    For each column of the input, a line of text is printed, resulting from the
    specified reduction or percentile operation. If -roi is specified without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Use -column to only give
    output for a single data column. Exactly one of -reduce or -percentile must
    be specified.
    
    The argument to the -reduce option must be one of the following:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Args:
        cifti_in: the input cifti.
        roi: only consider data inside an roi.
        column: only display output for one column\
            \
            the column index (starting from 1).
        percent: give the value at a percentile\
            \
            the percentile to find, must be between 0 and 100.
        operation: use a reduction operation\
            \
            the reduction operation.
        show_map_name: print column index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiStatsOutputs`).
    """
    params = cifti_stats_params(
        cifti_in=cifti_in,
        roi=roi,
        column=column,
        percent=percent,
        operation=operation,
        show_map_name=show_map_name,
    )
    return cifti_stats_execute(params, runner)


__all__ = [
    "CIFTI_STATS_METADATA",
    "CiftiStatsOutputs",
    "CiftiStatsParamsDict",
    "CiftiStatsParamsDictTagged",
    "CiftiStatsRoiParamsDict",
    "CiftiStatsRoiParamsDictTagged",
    "cifti_stats",
    "cifti_stats_execute",
    "cifti_stats_params",
    "cifti_stats_roi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_GRADIENT_METADATA = Metadata(
    id="d2460b1cd46e52f13e61657937e6834a86e13b49.workbench",
    name="cifti-gradient",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_CiftiGradientLeftSurfaceParamsDictNoTag = typing.TypedDict('_CiftiGradientLeftSurfaceParamsDictNoTag', {
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientLeftSurfaceParamsDictTagged = typing.TypedDict('CiftiGradientLeftSurfaceParamsDictTagged', {
    "@type": typing.Literal["left-surface"],
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientLeftSurfaceParamsDict = _CiftiGradientLeftSurfaceParamsDictNoTag | CiftiGradientLeftSurfaceParamsDictTagged


_CiftiGradientRightSurfaceParamsDictNoTag = typing.TypedDict('_CiftiGradientRightSurfaceParamsDictNoTag', {
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientRightSurfaceParamsDictTagged = typing.TypedDict('CiftiGradientRightSurfaceParamsDictTagged', {
    "@type": typing.Literal["right-surface"],
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientRightSurfaceParamsDict = _CiftiGradientRightSurfaceParamsDictNoTag | CiftiGradientRightSurfaceParamsDictTagged


_CiftiGradientCerebellumSurfaceParamsDictNoTag = typing.TypedDict('_CiftiGradientCerebellumSurfaceParamsDictNoTag', {
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientCerebellumSurfaceParamsDictTagged = typing.TypedDict('CiftiGradientCerebellumSurfaceParamsDictTagged', {
    "@type": typing.Literal["cerebellum-surface"],
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientCerebellumSurfaceParamsDict = _CiftiGradientCerebellumSurfaceParamsDictNoTag | CiftiGradientCerebellumSurfaceParamsDictTagged


_CiftiGradientVectorsParamsDictNoTag = typing.TypedDict('_CiftiGradientVectorsParamsDictNoTag', {
    "vectors-out": str,
})
CiftiGradientVectorsParamsDictTagged = typing.TypedDict('CiftiGradientVectorsParamsDictTagged', {
    "@type": typing.Literal["vectors"],
    "vectors-out": str,
})
CiftiGradientVectorsParamsDict = _CiftiGradientVectorsParamsDictNoTag | CiftiGradientVectorsParamsDictTagged


_CiftiGradientSurfaceParamsDictNoTag = typing.TypedDict('_CiftiGradientSurfaceParamsDictNoTag', {
    "structure": str,
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientSurfaceParamsDictTagged = typing.TypedDict('CiftiGradientSurfaceParamsDictTagged', {
    "@type": typing.Literal["surface"],
    "structure": str,
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiGradientSurfaceParamsDict = _CiftiGradientSurfaceParamsDictNoTag | CiftiGradientSurfaceParamsDictTagged


_CiftiGradientParamsDictNoTag = typing.TypedDict('_CiftiGradientParamsDictNoTag', {
    "cifti": InputPathType,
    "direction": str,
    "cifti-out": str,
    "left-surface": typing.NotRequired[CiftiGradientLeftSurfaceParamsDict | None],
    "right-surface": typing.NotRequired[CiftiGradientRightSurfaceParamsDict | None],
    "cerebellum-surface": typing.NotRequired[CiftiGradientCerebellumSurfaceParamsDict | None],
    "vectors": typing.NotRequired[CiftiGradientVectorsParamsDict | None],
    "surface": typing.NotRequired[list[CiftiGradientSurfaceParamsDict] | None],
    "volume-kernel": typing.NotRequired[float | None],
    "surface-kernel": typing.NotRequired[float | None],
    "average-output": bool,
    "presmooth-fwhm": bool,
})
CiftiGradientParamsDictTagged = typing.TypedDict('CiftiGradientParamsDictTagged', {
    "@type": typing.Literal["workbench/cifti-gradient"],
    "cifti": InputPathType,
    "direction": str,
    "cifti-out": str,
    "left-surface": typing.NotRequired[CiftiGradientLeftSurfaceParamsDict | None],
    "right-surface": typing.NotRequired[CiftiGradientRightSurfaceParamsDict | None],
    "cerebellum-surface": typing.NotRequired[CiftiGradientCerebellumSurfaceParamsDict | None],
    "vectors": typing.NotRequired[CiftiGradientVectorsParamsDict | None],
    "surface": typing.NotRequired[list[CiftiGradientSurfaceParamsDict] | None],
    "volume-kernel": typing.NotRequired[float | None],
    "surface-kernel": typing.NotRequired[float | None],
    "average-output": bool,
    "presmooth-fwhm": bool,
})
CiftiGradientParamsDict = _CiftiGradientParamsDictNoTag | CiftiGradientParamsDictTagged


def cifti_gradient_left_surface(
    surface: InputPathType,
    area_metric: InputPathType | None = None,
) -> CiftiGradientLeftSurfaceParamsDictTagged:
    """
    Build parameters.
    
    Args:
        surface: the left surface file.
        area_metric: vertex areas to use instead of computing them from the\
            left surface\
            \
            the corrected vertex areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left-surface",
        "surface": surface,
    }
    if area_metric is not None:
        params["area-metric"] = area_metric
    return params


def cifti_gradient_left_surface_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiGradientLeftSurfaceParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("surface", None) is None:
        raise StyxValidationError("`surface` must not be None")
    if not isinstance(params["surface"], (pathlib.Path, str)):
        raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `InputPathType`')
    if params.get("area-metric", None) is not None:
        if not isinstance(params["area-metric"], (pathlib.Path, str)):
            raise StyxValidationError(f'`area-metric` has the wrong type: Received `{type(params.get("area-metric", None))}` expected `InputPathType | None`')


def cifti_gradient_left_surface_cargs(
    params: CiftiGradientLeftSurfaceParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-left-surface",
        execution.input_file(params.get("surface", None))
    ])
    if params.get("area-metric", None) is not None:
        cargs.extend([
            "-left-corrected-areas",
            execution.input_file(params.get("area-metric", None))
        ])
    return cargs


def cifti_gradient_right_surface(
    surface: InputPathType,
    area_metric: InputPathType | None = None,
) -> CiftiGradientRightSurfaceParamsDictTagged:
    """
    Build parameters.
    
    Args:
        surface: the right surface file.
        area_metric: vertex areas to use instead of computing them from the\
            right surface\
            \
            the corrected vertex areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right-surface",
        "surface": surface,
    }
    if area_metric is not None:
        params["area-metric"] = area_metric
    return params


def cifti_gradient_right_surface_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiGradientRightSurfaceParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("surface", None) is None:
        raise StyxValidationError("`surface` must not be None")
    if not isinstance(params["surface"], (pathlib.Path, str)):
        raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `InputPathType`')
    if params.get("area-metric", None) is not None:
        if not isinstance(params["area-metric"], (pathlib.Path, str)):
            raise StyxValidationError(f'`area-metric` has the wrong type: Received `{type(params.get("area-metric", None))}` expected `InputPathType | None`')


def cifti_gradient_right_surface_cargs(
    params: CiftiGradientRightSurfaceParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-right-surface",
        execution.input_file(params.get("surface", None))
    ])
    if params.get("area-metric", None) is not None:
        cargs.extend([
            "-right-corrected-areas",
            execution.input_file(params.get("area-metric", None))
        ])
    return cargs


def cifti_gradient_cerebellum_surface(
    surface: InputPathType,
    area_metric: InputPathType | None = None,
) -> CiftiGradientCerebellumSurfaceParamsDictTagged:
    """
    Build parameters.
    
    Args:
        surface: the cerebellum surface file.
        area_metric: vertex areas to use instead of computing them from the\
            cerebellum surface\
            \
            the corrected vertex areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum-surface",
        "surface": surface,
    }
    if area_metric is not None:
        params["area-metric"] = area_metric
    return params


def cifti_gradient_cerebellum_surface_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiGradientCerebellumSurfaceParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("surface", None) is None:
        raise StyxValidationError("`surface` must not be None")
    if not isinstance(params["surface"], (pathlib.Path, str)):
        raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `InputPathType`')
    if params.get("area-metric", None) is not None:
        if not isinstance(params["area-metric"], (pathlib.Path, str)):
            raise StyxValidationError(f'`area-metric` has the wrong type: Received `{type(params.get("area-metric", None))}` expected `InputPathType | None`')


def cifti_gradient_cerebellum_surface_cargs(
    params: CiftiGradientCerebellumSurfaceParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-cerebellum-surface",
        execution.input_file(params.get("surface", None))
    ])
    if params.get("area-metric", None) is not None:
        cargs.extend([
            "-cerebellum-corrected-areas",
            execution.input_file(params.get("area-metric", None))
        ])
    return cargs


class CiftiGradientVectorsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiGradientVectorsParamsDict | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    vectors_out: OutputPathType
    """the vectors, as a dscalar file"""


def cifti_gradient_vectors(
    vectors_out: str,
) -> CiftiGradientVectorsParamsDictTagged:
    """
    Build parameters.
    
    Args:
        vectors_out: the vectors, as a dscalar file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "vectors",
        "vectors-out": vectors_out,
    }
    return params


def cifti_gradient_vectors_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiGradientVectorsParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("vectors-out", None) is None:
        raise StyxValidationError("`vectors-out` must not be None")
    if not isinstance(params["vectors-out"], str):
        raise StyxValidationError(f'`vectors-out` has the wrong type: Received `{type(params.get("vectors-out", None))}` expected `str`')


def cifti_gradient_vectors_cargs(
    params: CiftiGradientVectorsParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-vectors",
        params.get("vectors-out", None)
    ])
    return cargs


def cifti_gradient_vectors_outputs(
    params: CiftiGradientVectorsParamsDict,
    execution: Execution,
) -> CiftiGradientVectorsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiGradientVectorsOutputs(
        root=execution.output_file("."),
        vectors_out=execution.output_file(params.get("vectors-out", None)),
    )
    return ret


def cifti_gradient_surface(
    structure: str,
    surface: InputPathType,
    area_metric: InputPathType | None = None,
) -> CiftiGradientSurfaceParamsDictTagged:
    """
    Build parameters.
    
    Args:
        structure: the surface structure name.
        surface: the surface file.
        area_metric: vertex areas to use instead of computing them from the\
            surface\
            \
            the corrected vertex areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "surface",
        "structure": structure,
        "surface": surface,
    }
    if area_metric is not None:
        params["area-metric"] = area_metric
    return params


def cifti_gradient_surface_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiGradientSurfaceParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("structure", None) is None:
        raise StyxValidationError("`structure` must not be None")
    if not isinstance(params["structure"], str):
        raise StyxValidationError(f'`structure` has the wrong type: Received `{type(params.get("structure", None))}` expected `str`')
    if params.get("surface", None) is None:
        raise StyxValidationError("`surface` must not be None")
    if not isinstance(params["surface"], (pathlib.Path, str)):
        raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `InputPathType`')
    if params.get("area-metric", None) is not None:
        if not isinstance(params["area-metric"], (pathlib.Path, str)):
            raise StyxValidationError(f'`area-metric` has the wrong type: Received `{type(params.get("area-metric", None))}` expected `InputPathType | None`')


def cifti_gradient_surface_cargs(
    params: CiftiGradientSurfaceParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-surface",
        params.get("structure", None),
        execution.input_file(params.get("surface", None))
    ])
    if params.get("area-metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("area-metric", None))
        ])
    return cargs


class CiftiGradientOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiGradientParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""
    vectors: CiftiGradientVectorsOutputs | None
    """Outputs from `cifti_gradient_vectors_outputs`."""


def cifti_gradient_params(
    cifti: InputPathType,
    direction: str,
    cifti_out: str,
    left_surface: CiftiGradientLeftSurfaceParamsDict | None = None,
    right_surface: CiftiGradientRightSurfaceParamsDict | None = None,
    cerebellum_surface: CiftiGradientCerebellumSurfaceParamsDict | None = None,
    vectors: CiftiGradientVectorsParamsDict | None = None,
    surface: list[CiftiGradientSurfaceParamsDict] | None = None,
    volume_kernel: float | None = None,
    surface_kernel: float | None = None,
    average_output: bool = False,
    presmooth_fwhm: bool = False,
) -> CiftiGradientParamsDictTagged:
    """
    Build parameters.
    
    Args:
        cifti: the input cifti.
        direction: which dimension to take the gradient along, ROW or COLUMN.
        cifti_out: the output cifti.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        vectors: output gradient vectors.
        surface: specify a surface by structure name.
        volume_kernel: smooth on the surface before computing the gradient\
            \
            the size of the gaussian volume smoothing kernel in mm, as sigma by\
            default.
        surface_kernel: smooth on the surface before computing the gradient\
            \
            the size of the gaussian surface smoothing kernel in mm, as sigma\
            by default.
        average_output: output the average of the gradient magnitude maps\
            instead of each gradient map separately.
        presmooth_fwhm: smoothing kernel sizes are FWHM, not sigma.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-gradient",
        "cifti": cifti,
        "direction": direction,
        "cifti-out": cifti_out,
        "average-output": average_output,
        "presmooth-fwhm": presmooth_fwhm,
    }
    if left_surface is not None:
        params["left-surface"] = left_surface
    if right_surface is not None:
        params["right-surface"] = right_surface
    if cerebellum_surface is not None:
        params["cerebellum-surface"] = cerebellum_surface
    if vectors is not None:
        params["vectors"] = vectors
    if surface is not None:
        params["surface"] = surface
    if volume_kernel is not None:
        params["volume-kernel"] = volume_kernel
    if surface_kernel is not None:
        params["surface-kernel"] = surface_kernel
    return params


def cifti_gradient_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiGradientParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("cifti", None) is None:
        raise StyxValidationError("`cifti` must not be None")
    if not isinstance(params["cifti"], (pathlib.Path, str)):
        raise StyxValidationError(f'`cifti` has the wrong type: Received `{type(params.get("cifti", None))}` expected `InputPathType`')
    if params.get("direction", None) is None:
        raise StyxValidationError("`direction` must not be None")
    if not isinstance(params["direction"], str):
        raise StyxValidationError(f'`direction` has the wrong type: Received `{type(params.get("direction", None))}` expected `str`')
    if params.get("cifti-out", None) is None:
        raise StyxValidationError("`cifti-out` must not be None")
    if not isinstance(params["cifti-out"], str):
        raise StyxValidationError(f'`cifti-out` has the wrong type: Received `{type(params.get("cifti-out", None))}` expected `str`')
    if params.get("left-surface", None) is not None:
        cifti_gradient_left_surface_validate(params["left-surface"])
    if params.get("right-surface", None) is not None:
        cifti_gradient_right_surface_validate(params["right-surface"])
    if params.get("cerebellum-surface", None) is not None:
        cifti_gradient_cerebellum_surface_validate(params["cerebellum-surface"])
    if params.get("vectors", None) is not None:
        cifti_gradient_vectors_validate(params["vectors"])
    if params.get("surface", None) is not None:
        if not isinstance(params["surface"], list):
            raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `list[CiftiGradientSurfaceParamsDict] | None`')
        for e in params["surface"]:
            cifti_gradient_surface_validate(e)
    if params.get("volume-kernel", None) is not None:
        if not isinstance(params["volume-kernel"], (float, int)):
            raise StyxValidationError(f'`volume-kernel` has the wrong type: Received `{type(params.get("volume-kernel", None))}` expected `float | None`')
    if params.get("surface-kernel", None) is not None:
        if not isinstance(params["surface-kernel"], (float, int)):
            raise StyxValidationError(f'`surface-kernel` has the wrong type: Received `{type(params.get("surface-kernel", None))}` expected `float | None`')
    if params.get("average-output", False) is None:
        raise StyxValidationError("`average-output` must not be None")
    if not isinstance(params["average-output"], bool):
        raise StyxValidationError(f'`average-output` has the wrong type: Received `{type(params.get("average-output", False))}` expected `bool`')
    if params.get("presmooth-fwhm", False) is None:
        raise StyxValidationError("`presmooth-fwhm` must not be None")
    if not isinstance(params["presmooth-fwhm"], bool):
        raise StyxValidationError(f'`presmooth-fwhm` has the wrong type: Received `{type(params.get("presmooth-fwhm", False))}` expected `bool`')


def cifti_gradient_cargs(
    params: CiftiGradientParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-cifti-gradient"
    ])
    cargs.append(execution.input_file(params.get("cifti", None)))
    cargs.append(params.get("direction", None))
    cargs.append(params.get("cifti-out", None))
    if params.get("left-surface", None) is not None or params.get("right-surface", None) is not None or params.get("cerebellum-surface", None) is not None or params.get("vectors", None) is not None or params.get("surface", None) is not None:
        cargs.extend([
            *(cifti_gradient_left_surface_cargs(params.get("left-surface", None), execution) if (params.get("left-surface", None) is not None) else []),
            *(cifti_gradient_right_surface_cargs(params.get("right-surface", None), execution) if (params.get("right-surface", None) is not None) else []),
            *(cifti_gradient_cerebellum_surface_cargs(params.get("cerebellum-surface", None), execution) if (params.get("cerebellum-surface", None) is not None) else []),
            *(cifti_gradient_vectors_cargs(params.get("vectors", None), execution) if (params.get("vectors", None) is not None) else []),
            *([a for c in [cifti_gradient_surface_cargs(s, execution) for s in params.get("surface", None)] for a in c] if (params.get("surface", None) is not None) else [])
        ])
    if params.get("volume-kernel", None) is not None:
        cargs.extend([
            "-volume-presmooth",
            str(params.get("volume-kernel", None))
        ])
    if params.get("surface-kernel", None) is not None:
        cargs.extend([
            "-surface-presmooth",
            str(params.get("surface-kernel", None))
        ])
    if params.get("average-output", False):
        cargs.append("-average-output")
    if params.get("presmooth-fwhm", False):
        cargs.append("-presmooth-fwhm")
    return cargs


def cifti_gradient_outputs(
    params: CiftiGradientParamsDict,
    execution: Execution,
) -> CiftiGradientOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiGradientOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti-out", None)),
        vectors=cifti_gradient_vectors_outputs(params.get("vectors"), execution) if params.get("vectors") else None,
    )
    return ret


def cifti_gradient_execute(
    params: CiftiGradientParamsDict,
    runner: Runner | None = None,
) -> CiftiGradientOutputs:
    """
    TAKE GRADIENT OF A CIFTI FILE.
    
    Performs gradient calculation on each component of the cifti file, and
    optionally averages the resulting gradients. The -vectors and
    -average-output options may not be used together. You must specify a surface
    for each surface structure in the cifti file. The COLUMN direction should be
    faster, and is the direction that works on dtseries. For dconn, you probably
    want ROW, unless you are using -average-output.
    
    The <structure> argument to -surface must be one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    HIPPOCAMPUS_DENTATE_LEFT
    HIPPOCAMPUS_DENTATE_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiGradientOutputs`).
    """
    cifti_gradient_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_GRADIENT_METADATA)
    params = execution.params(params)
    cargs = cifti_gradient_cargs(params, execution)
    ret = cifti_gradient_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_gradient(
    cifti: InputPathType,
    direction: str,
    cifti_out: str,
    left_surface: CiftiGradientLeftSurfaceParamsDict | None = None,
    right_surface: CiftiGradientRightSurfaceParamsDict | None = None,
    cerebellum_surface: CiftiGradientCerebellumSurfaceParamsDict | None = None,
    vectors: CiftiGradientVectorsParamsDict | None = None,
    surface: list[CiftiGradientSurfaceParamsDict] | None = None,
    volume_kernel: float | None = None,
    surface_kernel: float | None = None,
    average_output: bool = False,
    presmooth_fwhm: bool = False,
    runner: Runner | None = None,
) -> CiftiGradientOutputs:
    """
    TAKE GRADIENT OF A CIFTI FILE.
    
    Performs gradient calculation on each component of the cifti file, and
    optionally averages the resulting gradients. The -vectors and
    -average-output options may not be used together. You must specify a surface
    for each surface structure in the cifti file. The COLUMN direction should be
    faster, and is the direction that works on dtseries. For dconn, you probably
    want ROW, unless you are using -average-output.
    
    The <structure> argument to -surface must be one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    HIPPOCAMPUS_DENTATE_LEFT
    HIPPOCAMPUS_DENTATE_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Args:
        cifti: the input cifti.
        direction: which dimension to take the gradient along, ROW or COLUMN.
        cifti_out: the output cifti.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        vectors: output gradient vectors.
        surface: specify a surface by structure name.
        volume_kernel: smooth on the surface before computing the gradient\
            \
            the size of the gaussian volume smoothing kernel in mm, as sigma by\
            default.
        surface_kernel: smooth on the surface before computing the gradient\
            \
            the size of the gaussian surface smoothing kernel in mm, as sigma\
            by default.
        average_output: output the average of the gradient magnitude maps\
            instead of each gradient map separately.
        presmooth_fwhm: smoothing kernel sizes are FWHM, not sigma.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiGradientOutputs`).
    """
    params = cifti_gradient_params(
        cifti=cifti,
        direction=direction,
        cifti_out=cifti_out,
        left_surface=left_surface,
        right_surface=right_surface,
        cerebellum_surface=cerebellum_surface,
        vectors=vectors,
        surface=surface,
        volume_kernel=volume_kernel,
        surface_kernel=surface_kernel,
        average_output=average_output,
        presmooth_fwhm=presmooth_fwhm,
    )
    return cifti_gradient_execute(params, runner)


__all__ = [
    "CIFTI_GRADIENT_METADATA",
    "CiftiGradientCerebellumSurfaceParamsDict",
    "CiftiGradientCerebellumSurfaceParamsDictTagged",
    "CiftiGradientLeftSurfaceParamsDict",
    "CiftiGradientLeftSurfaceParamsDictTagged",
    "CiftiGradientOutputs",
    "CiftiGradientParamsDict",
    "CiftiGradientParamsDictTagged",
    "CiftiGradientRightSurfaceParamsDict",
    "CiftiGradientRightSurfaceParamsDictTagged",
    "CiftiGradientSurfaceParamsDict",
    "CiftiGradientSurfaceParamsDictTagged",
    "CiftiGradientVectorsOutputs",
    "CiftiGradientVectorsParamsDict",
    "CiftiGradientVectorsParamsDictTagged",
    "cifti_gradient",
    "cifti_gradient_cerebellum_surface",
    "cifti_gradient_execute",
    "cifti_gradient_left_surface",
    "cifti_gradient_params",
    "cifti_gradient_right_surface",
    "cifti_gradient_surface",
    "cifti_gradient_vectors",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

FOCI_LIST_COORDS_METADATA = Metadata(
    id="b16ceca59fb70119f927e417ec349a0afda6a816.workbench",
    name="foci-list-coords",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_FociListCoordsParamsDictNoTag = typing.TypedDict('_FociListCoordsParamsDictNoTag', {
    "foci-file": InputPathType,
    "coord-file-out": str,
    "names-file-out": typing.NotRequired[str | None],
})
FociListCoordsParamsDictTagged = typing.TypedDict('FociListCoordsParamsDictTagged', {
    "@type": typing.Literal["workbench/foci-list-coords"],
    "foci-file": InputPathType,
    "coord-file-out": str,
    "names-file-out": typing.NotRequired[str | None],
})
FociListCoordsParamsDict = _FociListCoordsParamsDictNoTag | FociListCoordsParamsDictTagged


class FociListCoordsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `FociListCoordsParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def foci_list_coords_params(
    foci_file: InputPathType,
    coord_file_out: str,
    names_file_out: str | None = None,
) -> FociListCoordsParamsDictTagged:
    """
    Build parameters.
    
    Args:
        foci_file: input foci file.
        coord_file_out: output - the output coordinate text file.
        names_file_out: output the foci names\
            \
            output - text file to put foci names in.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/foci-list-coords",
        "foci-file": foci_file,
        "coord-file-out": coord_file_out,
    }
    if names_file_out is not None:
        params["names-file-out"] = names_file_out
    return params


def foci_list_coords_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `FociListCoordsParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("foci-file", None) is None:
        raise StyxValidationError("`foci-file` must not be None")
    if not isinstance(params["foci-file"], (pathlib.Path, str)):
        raise StyxValidationError(f'`foci-file` has the wrong type: Received `{type(params.get("foci-file", None))}` expected `InputPathType`')
    if params.get("coord-file-out", None) is None:
        raise StyxValidationError("`coord-file-out` must not be None")
    if not isinstance(params["coord-file-out"], str):
        raise StyxValidationError(f'`coord-file-out` has the wrong type: Received `{type(params.get("coord-file-out", None))}` expected `str`')
    if params.get("names-file-out", None) is not None:
        if not isinstance(params["names-file-out"], str):
            raise StyxValidationError(f'`names-file-out` has the wrong type: Received `{type(params.get("names-file-out", None))}` expected `str | None`')


def foci_list_coords_cargs(
    params: FociListCoordsParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-foci-list-coords"
    ])
    cargs.append(execution.input_file(params.get("foci-file", None)))
    cargs.append(params.get("coord-file-out", None))
    if params.get("names-file-out", None) is not None:
        cargs.extend([
            "-names-out",
            params.get("names-file-out", None)
        ])
    return cargs


def foci_list_coords_outputs(
    params: FociListCoordsParamsDict,
    execution: Execution,
) -> FociListCoordsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = FociListCoordsOutputs(
        root=execution.output_file("."),
    )
    return ret


def foci_list_coords_execute(
    params: FociListCoordsParamsDict,
    runner: Runner | None = None,
) -> FociListCoordsOutputs:
    """
    OUTPUT FOCI COORDINATES IN A TEXT FILE.
    
    Output the coordinates for every focus in the foci file, and optionally the
    focus names in a second text file.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociListCoordsOutputs`).
    """
    foci_list_coords_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(FOCI_LIST_COORDS_METADATA)
    params = execution.params(params)
    cargs = foci_list_coords_cargs(params, execution)
    ret = foci_list_coords_outputs(params, execution)
    execution.run(cargs)
    return ret


def foci_list_coords(
    foci_file: InputPathType,
    coord_file_out: str,
    names_file_out: str | None = None,
    runner: Runner | None = None,
) -> FociListCoordsOutputs:
    """
    OUTPUT FOCI COORDINATES IN A TEXT FILE.
    
    Output the coordinates for every focus in the foci file, and optionally the
    focus names in a second text file.
    
    Args:
        foci_file: input foci file.
        coord_file_out: output - the output coordinate text file.
        names_file_out: output the foci names\
            \
            output - text file to put foci names in.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociListCoordsOutputs`).
    """
    params = foci_list_coords_params(
        foci_file=foci_file,
        coord_file_out=coord_file_out,
        names_file_out=names_file_out,
    )
    return foci_list_coords_execute(params, runner)


__all__ = [
    "FOCI_LIST_COORDS_METADATA",
    "FociListCoordsOutputs",
    "FociListCoordsParamsDict",
    "FociListCoordsParamsDictTagged",
    "foci_list_coords",
    "foci_list_coords_execute",
    "foci_list_coords_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_ERODE_METADATA = Metadata(
    id="4f49d2de43c52dfd46795fc526b69cf0dadd9733.workbench",
    name="cifti-erode",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_CiftiErodeLeftSurfaceParamsDictNoTag = typing.TypedDict('_CiftiErodeLeftSurfaceParamsDictNoTag', {
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeLeftSurfaceParamsDictTagged = typing.TypedDict('CiftiErodeLeftSurfaceParamsDictTagged', {
    "@type": typing.Literal["left-surface"],
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeLeftSurfaceParamsDict = _CiftiErodeLeftSurfaceParamsDictNoTag | CiftiErodeLeftSurfaceParamsDictTagged


_CiftiErodeRightSurfaceParamsDictNoTag = typing.TypedDict('_CiftiErodeRightSurfaceParamsDictNoTag', {
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeRightSurfaceParamsDictTagged = typing.TypedDict('CiftiErodeRightSurfaceParamsDictTagged', {
    "@type": typing.Literal["right-surface"],
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeRightSurfaceParamsDict = _CiftiErodeRightSurfaceParamsDictNoTag | CiftiErodeRightSurfaceParamsDictTagged


_CiftiErodeCerebellumSurfaceParamsDictNoTag = typing.TypedDict('_CiftiErodeCerebellumSurfaceParamsDictNoTag', {
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeCerebellumSurfaceParamsDictTagged = typing.TypedDict('CiftiErodeCerebellumSurfaceParamsDictTagged', {
    "@type": typing.Literal["cerebellum-surface"],
    "surface": InputPathType,
    "area-metric": typing.NotRequired[InputPathType | None],
})
CiftiErodeCerebellumSurfaceParamsDict = _CiftiErodeCerebellumSurfaceParamsDictNoTag | CiftiErodeCerebellumSurfaceParamsDictTagged


_CiftiErodeParamsDictNoTag = typing.TypedDict('_CiftiErodeParamsDictNoTag', {
    "cifti-in": InputPathType,
    "direction": str,
    "surface-distance": float,
    "volume-distance": float,
    "cifti-out": str,
    "left-surface": typing.NotRequired[CiftiErodeLeftSurfaceParamsDict | None],
    "right-surface": typing.NotRequired[CiftiErodeRightSurfaceParamsDict | None],
    "cerebellum-surface": typing.NotRequired[CiftiErodeCerebellumSurfaceParamsDict | None],
    "merged-volume": bool,
})
CiftiErodeParamsDictTagged = typing.TypedDict('CiftiErodeParamsDictTagged', {
    "@type": typing.Literal["workbench/cifti-erode"],
    "cifti-in": InputPathType,
    "direction": str,
    "surface-distance": float,
    "volume-distance": float,
    "cifti-out": str,
    "left-surface": typing.NotRequired[CiftiErodeLeftSurfaceParamsDict | None],
    "right-surface": typing.NotRequired[CiftiErodeRightSurfaceParamsDict | None],
    "cerebellum-surface": typing.NotRequired[CiftiErodeCerebellumSurfaceParamsDict | None],
    "merged-volume": bool,
})
CiftiErodeParamsDict = _CiftiErodeParamsDictNoTag | CiftiErodeParamsDictTagged


def cifti_erode_left_surface(
    surface: InputPathType,
    area_metric: InputPathType | None = None,
) -> CiftiErodeLeftSurfaceParamsDictTagged:
    """
    Build parameters.
    
    Args:
        surface: the left surface file.
        area_metric: vertex areas to use instead of computing them from the\
            left surface\
            \
            the corrected vertex areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left-surface",
        "surface": surface,
    }
    if area_metric is not None:
        params["area-metric"] = area_metric
    return params


def cifti_erode_left_surface_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiErodeLeftSurfaceParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("surface", None) is None:
        raise StyxValidationError("`surface` must not be None")
    if not isinstance(params["surface"], (pathlib.Path, str)):
        raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `InputPathType`')
    if params.get("area-metric", None) is not None:
        if not isinstance(params["area-metric"], (pathlib.Path, str)):
            raise StyxValidationError(f'`area-metric` has the wrong type: Received `{type(params.get("area-metric", None))}` expected `InputPathType | None`')


def cifti_erode_left_surface_cargs(
    params: CiftiErodeLeftSurfaceParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-left-surface",
        execution.input_file(params.get("surface", None))
    ])
    if params.get("area-metric", None) is not None:
        cargs.extend([
            "-left-corrected-areas",
            execution.input_file(params.get("area-metric", None))
        ])
    return cargs


def cifti_erode_right_surface(
    surface: InputPathType,
    area_metric: InputPathType | None = None,
) -> CiftiErodeRightSurfaceParamsDictTagged:
    """
    Build parameters.
    
    Args:
        surface: the right surface file.
        area_metric: vertex areas to use instead of computing them from the\
            right surface\
            \
            the corrected vertex areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right-surface",
        "surface": surface,
    }
    if area_metric is not None:
        params["area-metric"] = area_metric
    return params


def cifti_erode_right_surface_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiErodeRightSurfaceParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("surface", None) is None:
        raise StyxValidationError("`surface` must not be None")
    if not isinstance(params["surface"], (pathlib.Path, str)):
        raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `InputPathType`')
    if params.get("area-metric", None) is not None:
        if not isinstance(params["area-metric"], (pathlib.Path, str)):
            raise StyxValidationError(f'`area-metric` has the wrong type: Received `{type(params.get("area-metric", None))}` expected `InputPathType | None`')


def cifti_erode_right_surface_cargs(
    params: CiftiErodeRightSurfaceParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-right-surface",
        execution.input_file(params.get("surface", None))
    ])
    if params.get("area-metric", None) is not None:
        cargs.extend([
            "-right-corrected-areas",
            execution.input_file(params.get("area-metric", None))
        ])
    return cargs


def cifti_erode_cerebellum_surface(
    surface: InputPathType,
    area_metric: InputPathType | None = None,
) -> CiftiErodeCerebellumSurfaceParamsDictTagged:
    """
    Build parameters.
    
    Args:
        surface: the cerebellum surface file.
        area_metric: vertex areas to use instead of computing them from the\
            cerebellum surface\
            \
            the corrected vertex areas, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum-surface",
        "surface": surface,
    }
    if area_metric is not None:
        params["area-metric"] = area_metric
    return params


def cifti_erode_cerebellum_surface_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiErodeCerebellumSurfaceParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("surface", None) is None:
        raise StyxValidationError("`surface` must not be None")
    if not isinstance(params["surface"], (pathlib.Path, str)):
        raise StyxValidationError(f'`surface` has the wrong type: Received `{type(params.get("surface", None))}` expected `InputPathType`')
    if params.get("area-metric", None) is not None:
        if not isinstance(params["area-metric"], (pathlib.Path, str)):
            raise StyxValidationError(f'`area-metric` has the wrong type: Received `{type(params.get("area-metric", None))}` expected `InputPathType | None`')


def cifti_erode_cerebellum_surface_cargs(
    params: CiftiErodeCerebellumSurfaceParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "-cerebellum-surface",
        execution.input_file(params.get("surface", None))
    ])
    if params.get("area-metric", None) is not None:
        cargs.extend([
            "-cerebellum-corrected-areas",
            execution.input_file(params.get("area-metric", None))
        ])
    return cargs


class CiftiErodeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiErodeParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_erode_params(
    cifti_in: InputPathType,
    direction: str,
    surface_distance: float,
    volume_distance: float,
    cifti_out: str,
    left_surface: CiftiErodeLeftSurfaceParamsDict | None = None,
    right_surface: CiftiErodeRightSurfaceParamsDict | None = None,
    cerebellum_surface: CiftiErodeCerebellumSurfaceParamsDict | None = None,
    merged_volume: bool = False,
) -> CiftiErodeParamsDictTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti file.
        direction: which dimension to dilate along, ROW or COLUMN.
        surface_distance: the distance to dilate on surfaces, in mm.
        volume_distance: the distance to dilate in the volume, in mm.
        cifti_out: the output cifti file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        merged_volume: treat volume components as if they were a single\
            component.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-erode",
        "cifti-in": cifti_in,
        "direction": direction,
        "surface-distance": surface_distance,
        "volume-distance": volume_distance,
        "cifti-out": cifti_out,
        "merged-volume": merged_volume,
    }
    if left_surface is not None:
        params["left-surface"] = left_surface
    if right_surface is not None:
        params["right-surface"] = right_surface
    if cerebellum_surface is not None:
        params["cerebellum-surface"] = cerebellum_surface
    return params


def cifti_erode_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `CiftiErodeParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("cifti-in", None) is None:
        raise StyxValidationError("`cifti-in` must not be None")
    if not isinstance(params["cifti-in"], (pathlib.Path, str)):
        raise StyxValidationError(f'`cifti-in` has the wrong type: Received `{type(params.get("cifti-in", None))}` expected `InputPathType`')
    if params.get("direction", None) is None:
        raise StyxValidationError("`direction` must not be None")
    if not isinstance(params["direction"], str):
        raise StyxValidationError(f'`direction` has the wrong type: Received `{type(params.get("direction", None))}` expected `str`')
    if params.get("surface-distance", None) is None:
        raise StyxValidationError("`surface-distance` must not be None")
    if not isinstance(params["surface-distance"], (float, int)):
        raise StyxValidationError(f'`surface-distance` has the wrong type: Received `{type(params.get("surface-distance", None))}` expected `float`')
    if params.get("volume-distance", None) is None:
        raise StyxValidationError("`volume-distance` must not be None")
    if not isinstance(params["volume-distance"], (float, int)):
        raise StyxValidationError(f'`volume-distance` has the wrong type: Received `{type(params.get("volume-distance", None))}` expected `float`')
    if params.get("cifti-out", None) is None:
        raise StyxValidationError("`cifti-out` must not be None")
    if not isinstance(params["cifti-out"], str):
        raise StyxValidationError(f'`cifti-out` has the wrong type: Received `{type(params.get("cifti-out", None))}` expected `str`')
    if params.get("left-surface", None) is not None:
        cifti_erode_left_surface_validate(params["left-surface"])
    if params.get("right-surface", None) is not None:
        cifti_erode_right_surface_validate(params["right-surface"])
    if params.get("cerebellum-surface", None) is not None:
        cifti_erode_cerebellum_surface_validate(params["cerebellum-surface"])
    if params.get("merged-volume", False) is None:
        raise StyxValidationError("`merged-volume` must not be None")
    if not isinstance(params["merged-volume"], bool):
        raise StyxValidationError(f'`merged-volume` has the wrong type: Received `{type(params.get("merged-volume", False))}` expected `bool`')


def cifti_erode_cargs(
    params: CiftiErodeParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-cifti-erode"
    ])
    cargs.append(execution.input_file(params.get("cifti-in", None)))
    cargs.append(params.get("direction", None))
    cargs.append(str(params.get("surface-distance", None)))
    cargs.append(str(params.get("volume-distance", None)))
    cargs.append(params.get("cifti-out", None))
    if params.get("left-surface", None) is not None or params.get("right-surface", None) is not None or params.get("cerebellum-surface", None) is not None:
        cargs.extend([
            *(cifti_erode_left_surface_cargs(params.get("left-surface", None), execution) if (params.get("left-surface", None) is not None) else []),
            *(cifti_erode_right_surface_cargs(params.get("right-surface", None), execution) if (params.get("right-surface", None) is not None) else []),
            *(cifti_erode_cerebellum_surface_cargs(params.get("cerebellum-surface", None), execution) if (params.get("cerebellum-surface", None) is not None) else [])
        ])
    if params.get("merged-volume", False):
        cargs.append("-merged-volume")
    return cargs


def cifti_erode_outputs(
    params: CiftiErodeParamsDict,
    execution: Execution,
) -> CiftiErodeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiErodeOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti-out", None)),
    )
    return ret


def cifti_erode_execute(
    params: CiftiErodeParamsDict,
    runner: Runner | None = None,
) -> CiftiErodeOutputs:
    """
    ERODE A CIFTI FILE.
    
    For all data values that are empty (for label data, unlabeled, for other
    data, zero), set the surrounding values to empty. The surrounding values are
    defined as the immediate neighbors and all values in the same structure
    within the specified distance (-merged-volume treats all voxels as one
    structure).
    
    The -*-corrected-areas options are intended for eroding on group average
    surfaces, but it is only an approximate correction.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiErodeOutputs`).
    """
    cifti_erode_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ERODE_METADATA)
    params = execution.params(params)
    cargs = cifti_erode_cargs(params, execution)
    ret = cifti_erode_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_erode(
    cifti_in: InputPathType,
    direction: str,
    surface_distance: float,
    volume_distance: float,
    cifti_out: str,
    left_surface: CiftiErodeLeftSurfaceParamsDict | None = None,
    right_surface: CiftiErodeRightSurfaceParamsDict | None = None,
    cerebellum_surface: CiftiErodeCerebellumSurfaceParamsDict | None = None,
    merged_volume: bool = False,
    runner: Runner | None = None,
) -> CiftiErodeOutputs:
    """
    ERODE A CIFTI FILE.
    
    For all data values that are empty (for label data, unlabeled, for other
    data, zero), set the surrounding values to empty. The surrounding values are
    defined as the immediate neighbors and all values in the same structure
    within the specified distance (-merged-volume treats all voxels as one
    structure).
    
    The -*-corrected-areas options are intended for eroding on group average
    surfaces, but it is only an approximate correction.
    
    Args:
        cifti_in: the input cifti file.
        direction: which dimension to dilate along, ROW or COLUMN.
        surface_distance: the distance to dilate on surfaces, in mm.
        volume_distance: the distance to dilate in the volume, in mm.
        cifti_out: the output cifti file.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        merged_volume: treat volume components as if they were a single\
            component.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiErodeOutputs`).
    """
    params = cifti_erode_params(
        cifti_in=cifti_in,
        direction=direction,
        surface_distance=surface_distance,
        volume_distance=volume_distance,
        cifti_out=cifti_out,
        left_surface=left_surface,
        right_surface=right_surface,
        cerebellum_surface=cerebellum_surface,
        merged_volume=merged_volume,
    )
    return cifti_erode_execute(params, runner)


__all__ = [
    "CIFTI_ERODE_METADATA",
    "CiftiErodeCerebellumSurfaceParamsDict",
    "CiftiErodeCerebellumSurfaceParamsDictTagged",
    "CiftiErodeLeftSurfaceParamsDict",
    "CiftiErodeLeftSurfaceParamsDictTagged",
    "CiftiErodeOutputs",
    "CiftiErodeParamsDict",
    "CiftiErodeParamsDictTagged",
    "CiftiErodeRightSurfaceParamsDict",
    "CiftiErodeRightSurfaceParamsDictTagged",
    "cifti_erode",
    "cifti_erode_cerebellum_surface",
    "cifti_erode_execute",
    "cifti_erode_left_surface",
    "cifti_erode_params",
    "cifti_erode_right_surface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_GENERATE_INFLATED_METADATA = Metadata(
    id="355a98e0d7f2dd37d2a8db3706f4c44d3c0fd8e8.workbench",
    name="surface-generate-inflated",
    package="workbench",
    container_image_tag="nx10x/workbench:2.1.0",
)


_SurfaceGenerateInflatedParamsDictNoTag = typing.TypedDict('_SurfaceGenerateInflatedParamsDictNoTag', {
    "anatomical-surface-in": InputPathType,
    "inflated-surface-out": str,
    "very-inflated-surface-out": str,
    "iterations-scale-value": typing.NotRequired[float | None],
})
SurfaceGenerateInflatedParamsDictTagged = typing.TypedDict('SurfaceGenerateInflatedParamsDictTagged', {
    "@type": typing.Literal["workbench/surface-generate-inflated"],
    "anatomical-surface-in": InputPathType,
    "inflated-surface-out": str,
    "very-inflated-surface-out": str,
    "iterations-scale-value": typing.NotRequired[float | None],
})
SurfaceGenerateInflatedParamsDict = _SurfaceGenerateInflatedParamsDictNoTag | SurfaceGenerateInflatedParamsDictTagged


class SurfaceGenerateInflatedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceGenerateInflatedParamsDict(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inflated_surface_out: OutputPathType
    """the output inflated surface"""
    very_inflated_surface_out: OutputPathType
    """the output very inflated surface"""


def surface_generate_inflated_params(
    anatomical_surface_in: InputPathType,
    inflated_surface_out: str,
    very_inflated_surface_out: str,
    iterations_scale_value: float | None = None,
) -> SurfaceGenerateInflatedParamsDictTagged:
    """
    Build parameters.
    
    Args:
        anatomical_surface_in: the anatomical surface.
        inflated_surface_out: the output inflated surface.
        very_inflated_surface_out: the output very inflated surface.
        iterations_scale_value: optional iterations scaling\
            \
            iterations-scale value.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-generate-inflated",
        "anatomical-surface-in": anatomical_surface_in,
        "inflated-surface-out": inflated_surface_out,
        "very-inflated-surface-out": very_inflated_surface_out,
    }
    if iterations_scale_value is not None:
        params["iterations-scale-value"] = iterations_scale_value
    return params


def surface_generate_inflated_validate(
    params: typing.Any,
) -> None:
    """
    Validate parameters. Throws an error if `params` is not a valid
    `SurfaceGenerateInflatedParamsDict` object.
    
    Args:
        params: The parameters object to validate.
    """
    if params is None or not isinstance(params, dict):
        raise StyxValidationError(f'Params object has the wrong type \'{type(params)}\'')
    if params.get("anatomical-surface-in", None) is None:
        raise StyxValidationError("`anatomical-surface-in` must not be None")
    if not isinstance(params["anatomical-surface-in"], (pathlib.Path, str)):
        raise StyxValidationError(f'`anatomical-surface-in` has the wrong type: Received `{type(params.get("anatomical-surface-in", None))}` expected `InputPathType`')
    if params.get("inflated-surface-out", None) is None:
        raise StyxValidationError("`inflated-surface-out` must not be None")
    if not isinstance(params["inflated-surface-out"], str):
        raise StyxValidationError(f'`inflated-surface-out` has the wrong type: Received `{type(params.get("inflated-surface-out", None))}` expected `str`')
    if params.get("very-inflated-surface-out", None) is None:
        raise StyxValidationError("`very-inflated-surface-out` must not be None")
    if not isinstance(params["very-inflated-surface-out"], str):
        raise StyxValidationError(f'`very-inflated-surface-out` has the wrong type: Received `{type(params.get("very-inflated-surface-out", None))}` expected `str`')
    if params.get("iterations-scale-value", None) is not None:
        if not isinstance(params["iterations-scale-value"], (float, int)):
            raise StyxValidationError(f'`iterations-scale-value` has the wrong type: Received `{type(params.get("iterations-scale-value", None))}` expected `float | None`')


def surface_generate_inflated_cargs(
    params: SurfaceGenerateInflatedParamsDict,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.extend([
        "wb_command",
        "-surface-generate-inflated"
    ])
    cargs.append(execution.input_file(params.get("anatomical-surface-in", None)))
    cargs.append(params.get("inflated-surface-out", None))
    cargs.append(params.get("very-inflated-surface-out", None))
    if params.get("iterations-scale-value", None) is not None:
        cargs.extend([
            "-iterations-scale",
            str(params.get("iterations-scale-value", None))
        ])
    return cargs


def surface_generate_inflated_outputs(
    params: SurfaceGenerateInflatedParamsDict,
    execution: Execution,
) -> SurfaceGenerateInflatedOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceGenerateInflatedOutputs(
        root=execution.output_file("."),
        inflated_surface_out=execution.output_file(params.get("inflated-surface-out", None)),
        very_inflated_surface_out=execution.output_file(params.get("very-inflated-surface-out", None)),
    )
    return ret


def surface_generate_inflated_execute(
    params: SurfaceGenerateInflatedParamsDict,
    runner: Runner | None = None,
) -> SurfaceGenerateInflatedOutputs:
    """
    SURFACE GENERATE INFLATED.
    
    Generate inflated and very inflated surfaces. The output surfaces are
    'matched' (have same XYZ range) to the anatomical surface. In most cases, an
    iterations-scale of 1.0 (default) is sufficient. However, if the surface
    contains a large number of vertices (150,000), try an iterations-scale of
    2.5.
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGenerateInflatedOutputs`).
    """
    surface_generate_inflated_validate(params)
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_GENERATE_INFLATED_METADATA)
    params = execution.params(params)
    cargs = surface_generate_inflated_cargs(params, execution)
    ret = surface_generate_inflated_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_generate_inflated(
    anatomical_surface_in: InputPathType,
    inflated_surface_out: str,
    very_inflated_surface_out: str,
    iterations_scale_value: float | None = None,
    runner: Runner | None = None,
) -> SurfaceGenerateInflatedOutputs:
    """
    SURFACE GENERATE INFLATED.
    
    Generate inflated and very inflated surfaces. The output surfaces are
    'matched' (have same XYZ range) to the anatomical surface. In most cases, an
    iterations-scale of 1.0 (default) is sufficient. However, if the surface
    contains a large number of vertices (150,000), try an iterations-scale of
    2.5.
    
    Args:
        anatomical_surface_in: the anatomical surface.
        inflated_surface_out: the output inflated surface.
        very_inflated_surface_out: the output very inflated surface.
        iterations_scale_value: optional iterations scaling\
            \
            iterations-scale value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGenerateInflatedOutputs`).
    """
    params = surface_generate_inflated_params(
        anatomical_surface_in=anatomical_surface_in,
        inflated_surface_out=inflated_surface_out,
        very_inflated_surface_out=very_inflated_surface_out,
        iterations_scale_value=iterations_scale_value,
    )
    return surface_generate_inflated_execute(params, runner)


__all__ = [
    "SURFACE_GENERATE_INFLATED_METADATA",
    "SurfaceGenerateInflatedOutputs",
    "SurfaceGenerateInflatedParamsDict",
    "SurfaceGenerateInflatedParamsDictTagged",
    "surface_generate_inflated",
    "surface_generate_inflated_execute",
    "surface_generate_inflated_params",
]
